@@ -1001,11 +1001,11 @@ def nais_processor(config_file):
     list_of_datetimes = pd.date_range(start=start_date_str, end=end_date_str)
 
     # list existing dates
-    list_of_existing_dates = [x['timestamp'] for x in db.search(check.diagnostics.exists())]
+    list_of_existing_dates = [x["timestamp"] for x in db.search(check.diagnostics.exists())]
 
     # Add unprocessed datafiles to the database
     for x in list_of_datetimes:
-        if (x.strftime('%Y%m%d') in list_of_existing_dates):
+        if (x.strftime("%Y%m%d") in list_of_existing_dates):
             continue
         else:
             files_found=False
@@ -1021,21 +1021,21 @@ def nais_processor(config_file):
                          os.path.exists(diagnostic_fn) # diagnostics
                        ):
 
-                        dtstr = x.strftime('%Y%m%d')
+                        dtstr = x.strftime("%Y%m%d")
 
                         db.insert(
-                            {'timestamp':dtstr,
-                            'diagnostics':diagnostic_fn}
+                            {"timestamp":dtstr,
+                            "diagnostics":diagnostic_fn}
                             )
 
                         if os.path.exists(ion_fn):
                             db.update(
-                                {'ions':ion_fn},
+                                {"ions":ion_fn},
                                 check.timestamp==dtstr)
 
                         if os.path.exists(particle_fn):
                             db.update(
-                                {'particles':particle_fn},
+                                {"particles":particle_fn},
                                 check.timestamp==dtstr)
 
                         files_found=True
@@ -1052,7 +1052,7 @@ def nais_processor(config_file):
         check.processed_pos_particle_file.exists())
 
     if len(processed_days)!=0:
-        last_day=np.max([datetime.strptime(x['timestamp'],'%Y%m%d') for x in processed_days]).strftime('%Y%m%d')
+        last_day=np.max([datetime.strptime(x["timestamp"],"%Y%m%d") for x in processed_days]).strftime("%Y%m%d")
     else:
         last_day=None
 
@@ -1088,23 +1088,23 @@ def nais_processor(config_file):
 
     for x in iterator:
 
-        print('processing %s' % x['timestamp'])
+        print("processing %s" % x["timestamp"])
 
         # Read the diagnostics
-        records = read_file(x['diagnostics'])
+        records = read_file(x["diagnostics"])
 
         ions_exist=db.search(
             check.ions.exists() &
-            (check.timestamp==x['timestamp']))
+            (check.timestamp==x["timestamp"]))
         particles_exist=db.search(
             check.particles.exists() &
-            (check.timestamp==x['timestamp']))
+            (check.timestamp==x["timestamp"]))
 
 
         # ions
         if ions_exist:
 
-            ions = read_file(x['ions'])
+            ions = read_file(x["ions"])
             ion_datamatrices = process_data(
                  ions,
                  records,
@@ -1116,36 +1116,36 @@ def nais_processor(config_file):
             if ion_datamatrices is not None:
 
                 # Save the sum matrices using the standard names
-                my_save_path_neg=os.path.join(save_path,'NAISn'+x['timestamp']+'nds.sum')
-                my_save_path_pos=os.path.join(save_path,'NAISp'+x['timestamp']+'nds.sum')
+                my_save_path_neg=os.path.join(save_path,"NAISn"+x["timestamp"]+"nds.sum")
+                my_save_path_pos=os.path.join(save_path,"NAISp"+x["timestamp"]+"nds.sum")
                 np.savetxt(my_save_path_neg,ion_datamatrices[0])
                 np.savetxt(my_save_path_pos,ion_datamatrices[1])
 
                 # Update the database
                 db.update(
-                    {'processed_neg_ion_file': my_save_path_neg,
-                    'processed_pos_ion_file': my_save_path_pos},
-                    check.timestamp==x['timestamp'])
+                    {"processed_neg_ion_file": my_save_path_neg,
+                    "processed_pos_ion_file": my_save_path_pos},
+                    check.timestamp==x["timestamp"])
 
                 if apply_cleaning:
-                    negion_datamatrix_cleaned = data_cleaner(ion_datamatrices[0],'ions')
-                    posion_datamatrix_cleaned = data_cleaner(ion_datamatrices[1],'ions')
+                    negion_datamatrix_cleaned = data_cleaner(ion_datamatrices[0],"ions")
+                    posion_datamatrix_cleaned = data_cleaner(ion_datamatrices[1],"ions")
 
-                    my_save_path_neg=os.path.join(save_path,'NAISn'+x['timestamp']+'nds_cleaned.sum')
-                    my_save_path_pos=os.path.join(save_path,'NAISp'+x['timestamp']+'nds_cleaned.sum')
+                    my_save_path_neg=os.path.join(save_path,"NAISn"+x["timestamp"]+"nds_cleaned.sum")
+                    my_save_path_pos=os.path.join(save_path,"NAISp"+x["timestamp"]+"nds_cleaned.sum")
                     np.savetxt(my_save_path_neg,ion_datamatrices[0])
                     np.savetxt(my_save_path_pos,ion_datamatrices[1])
 
                     db.update(
-                        {'cleaned_processed_neg_ion_file': my_save_path_neg,
-                        'cleaned_processed_pos_ion_file': my_save_path_pos },
-                        check.timestamp==x['timestamp'])
+                        {"cleaned_processed_neg_ion_file": my_save_path_neg,
+                        "cleaned_processed_pos_ion_file": my_save_path_pos },
+                        check.timestamp==x["timestamp"])
 
         # particles
         if particles_exist:
 
             # Process particles
-            particles = read_file(x['particles'])
+            particles = read_file(x["particles"])
             particle_datamatrices = process_data(
                 particles,
                 records,
@@ -1157,16 +1157,16 @@ def nais_processor(config_file):
             if particle_datamatrices is not None:
 
                 # Save the sum matrices using the standard names
-                my_save_path_neg=os.path.join(save_path,'NAISn'+x['timestamp']+'np.sum')
-                my_save_path_pos=os.path.join(save_path,'NAISp'+x['timestamp']+'np.sum')
+                my_save_path_neg=os.path.join(save_path,"NAISn"+x["timestamp"]+"np.sum")
+                my_save_path_pos=os.path.join(save_path,"NAISp"+x["timestamp"]+"np.sum")
                 np.savetxt(my_save_path_neg,particle_datamatrices[0])
                 np.savetxt(my_save_path_pos,particle_datamatrices[1])
 
                 # Update the database
                 db.update(
-                    {'processed_neg_particle_file': my_save_path_neg,
-                    'processed_pos_particle_file': my_save_path_pos},
-                    check.timestamp==x['timestamp'])
+                    {"processed_neg_particle_file": my_save_path_neg,
+                    "processed_pos_particle_file": my_save_path_pos},
+                    check.timestamp==x["timestamp"])
 
                 if apply_cleaning:
                     negpar_datamatrix_cleaned = particle_datamatrices[0].copy()
@@ -1175,18 +1175,18 @@ def nais_processor(config_file):
                     negpar_datamatrix_cleaned = corona_ion_cleaner(negpar_datamatrix_cleaned)
                     pospar_datamatrix_cleaned = corona_ion_cleaner(pospar_datamatrix_cleaned)
 
-                    negpar_datamatrix_cleaned = data_cleaner(negpar_datamatrix_cleaned,'particles')
-                    negpar_datamatrix_cleaned = data_cleaner(pospar_datamatrix_cleaned,'particles')
+                    negpar_datamatrix_cleaned = data_cleaner(negpar_datamatrix_cleaned,"particles")
+                    negpar_datamatrix_cleaned = data_cleaner(pospar_datamatrix_cleaned,"particles")
 
-                    my_save_path_neg=os.path.join(save_path,'NAISn'+x['timestamp']+'np_cleaned.sum')
-                    my_save_path_pos=os.path.join(save_path,'NAISp'+x['timestamp']+'np_cleaned.sum')
+                    my_save_path_neg=os.path.join(save_path,"NAISn"+x["timestamp"]+"np_cleaned.sum")
+                    my_save_path_pos=os.path.join(save_path,"NAISp"+x["timestamp"]+"np_cleaned.sum")
                     np.savetxt(my_save_path_neg,negpar_datamatrix_cleaned)
                     np.savetxt(my_save_path_pos,pospar_datamatrix_cleaned)
 
                     db.update(
-                        {'cleaned_processed_neg_particle_file': my_save_path_neg,
-                        'cleaned_processed_pos_particle_file': my_save_path_pos},
-                        check.timestamp==x['timestamp'])
+                        {"cleaned_processed_neg_particle_file": my_save_path_neg,
+                        "cleaned_processed_pos_particle_file": my_save_path_pos},
+                        check.timestamp==x["timestamp"])
 
     print("Done!")
 
